@@ -1,8 +1,5 @@
 package Net::Douban::Roles::More;
-
-BEGIN {
-    $Net::Douban::Roles::More::VERSION = '1.07_2';
-}
+our $VERSION = '1.03';
 
 use Carp qw/carp croak/;
 use Scalar::Util qw/blessed/;
@@ -11,23 +8,66 @@ use Moose::Role;
 with 'Net::Douban::Roles';
 
 has 'base_url' => (
-    is      => 'rw',
-    isa     => 'Url',
+    is      => 'ro',
     default => 'http://api.douban.com',
 );
 
 has 'user_url' => (
-    is      => 'rw',
-    isa     => 'Url',
+    is      => 'ro',
     default => 'http://api.douban.com/people',
 );
 
+has 'collection_url' => (
+    is      => 'ro',
+    default => 'http://api.douban.com/collection',
+);
+
+has 'subject_url' => (
+    is      => 'ro',
+    default => 'http://api.douban.com/subject',
+);
+
+has 'review_url' => (
+    is      => 'ro',
+    default => 'http://api.douban.com/review',
+);
+
+has 'miniblog_url' => (
+    is      => 'ro',
+    default => 'http://api.douban.com/miniblog',
+);
+
+has 'note_url' => (
+    is      => 'ro',
+    default => 'http://api.douban.com/note',
+);
+
+has 'event_url' => (
+    is      => 'ro',
+    default => 'http://api.douban.com/event',
+);
+
+has 'recommendation_url' => (
+    is      => 'ro',
+    default => 'http://api.douban.com/recommendation',
+);
+
+has 'doumail_url' => (
+    is      => 'ro',
+    default => "http://api.douban.com/doumail",
+);
+
+has 'token_url' => (
+    is      => 'ro',
+    default => 'http://api.douban.com/access_token',
+);
+
 sub get {
     my $self = shift;
     my $url  = shift;
     my %args = @_;
     my $response;
-    if ($self->has_oauth) {
+    if ($self->oauth) {
         $url = $self->build_url($url, %args);
         $response = $self->oauth->get($url) or croak $!;
     } else {
@@ -42,7 +82,7 @@ sub get {
 
 sub post {
     my ($self, $url, %args) = @_;
-    if ($self->has_oauth) {
+    if ($self->oauth) {
         my $response;
         if ($args{xml}) {
             $response =
@@ -51,7 +91,7 @@ sub post {
               ) or croak $!;
             croak $response->status_line unless $response->is_success;
         } else {
-            $response = $self->oauth->post(url => $url) or croak $!;
+            $response = $self->oauth->post(url => $url,) or croak $!;
             croak $response->status_line unless $response->is_success;
         }
         return $response;
@@ -62,7 +102,7 @@ sub post {
 
 sub put {
     my ($self, $url, %args) = @_;
-    if ($self->has_oauth) {
+    if ($self->oauth) {
         my $response =
           $self->oauth->put($url, $args{xml},
             ['Content-Type' => q{application/atom+xml}],
@@ -76,7 +116,7 @@ sub put {
 
 sub delete {
     my ($self, $url, %args) = @_;
-    if ($self->has_oauth) {
+    if ($self->oauth) {
         my $response = $self->oauth->delete($url,) or croak $!;
         croak $response->status_line unless $response->is_success;
         return $response;
@@ -91,7 +131,6 @@ sub build_url {
     my %args = @_;
     my $mark = $url =~ /\?/ ? '&' : '?';
     while (my ($key, $value) = each %args) {
-        $key =~ s/-/_/g;
         $url .= $mark . "$key=$value";
         $mark = '&';
     }
